@@ -3,17 +3,14 @@
 import gettext
 import datetime
 
-import pygtk
-
-pygtk.require('2.0')
-
 import gobject
 import gtk
 
 from dateutil.relativedelta import relativedelta
 from dateutil.parser import parse
 
-from datetime_strftime import datetime_strftime as strftime
+from .common import IconFactory
+from .datetime_strftime import datetime_strftime as strftime
 
 __all__ = ['Date', 'CellRendererDate', 'Time', 'CellRendererTime', 'DateTime']
 
@@ -21,9 +18,19 @@ _ = gettext.gettext
 
 
 def date_parse(text, format_='%x'):
+    try:
+        return datetime.datetime.strptime(text, format_)
+    except ValueError:
+        pass
     formatted_date = datetime.date(1988, 7, 16).strftime(format_)
-    dayfirst = formatted_date.index('16') == 0
-    monthfirst = formatted_date.index('7') <= 1
+    try:
+        dayfirst = formatted_date.index('16') == 0
+    except ValueError:
+        dayfirst = False
+    try:
+        monthfirst = formatted_date.index('7') <= 1
+    except ValueError:
+        monthfirst = False
     yearfirst = not dayfirst and not monthfirst
     return parse(text, dayfirst=dayfirst, yearfirst=yearfirst, ignoretz=True)
 
@@ -34,15 +41,16 @@ class Date(gtk.Entry):
         'value': (gobject.TYPE_PYOBJECT,
             _('Value'),
             _('Displayed value'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         'format': (gobject.TYPE_STRING,
             '%x',
             _('Format'),
             _('Display format'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         }
     __gsignals__ = {
-        'date-changed': (gobject.SIGNAL_RUN_LAST | gobject.SIGNAL_ACTION,
+        'date-changed': (
+            gobject.SignalFlags.RUN_LAST | gobject.SignalFlags.ACTION,
             gobject.TYPE_NONE, ()),
         }
 
@@ -52,14 +60,16 @@ class Date(gtk.Entry):
 
         gtk.Entry.__init__(self)
 
-        self.set_width_chars(12)
+        self.set_width_chars(20)
 
         self.connect('focus-out-event', self.focus_out)
         self.connect('activate', self.activate)
 
         # Calendar Popup
-        self.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY, 'tryton-find')
-        self.set_icon_tooltip_text(gtk.ENTRY_ICON_SECONDARY,
+        self.set_icon_from_pixbuf(
+            gtk.ENTRY_ICON_PRIMARY,
+            IconFactory.get_pixbuf('tryton-date', gtk.ICON_SIZE_MENU))
+        self.set_icon_tooltip_text(gtk.ENTRY_ICON_PRIMARY,
             _('Open the calendar'))
         self.connect('icon-press', self.icon_press)
 
@@ -99,7 +109,8 @@ class Date(gtk.Entry):
         self.set_text(strftime(self.__date, self.__format))
 
     def icon_press(self, entry, icon_pos, event):
-        if icon_pos == gtk.ENTRY_ICON_SECONDARY:
+        self.grab_focus()
+        if icon_pos == gtk.ENTRY_ICON_PRIMARY:
             self.cal_popup_open()
 
     def cal_popup_open(self):
@@ -164,7 +175,7 @@ class Date(gtk.Entry):
 
     def do_set_property(self, prop, value):
         if prop.name == 'value':
-            if isinstance(value, basestring):
+            if isinstance(value, str):
                 self.set_text(value)
                 self.parse()
                 value = self.__date
@@ -184,6 +195,7 @@ class Date(gtk.Entry):
         elif prop.name == 'format':
             return self.__format
 
+
 gobject.type_register(Date)
 
 
@@ -193,7 +205,7 @@ class CellRendererDate(gtk.CellRendererText):
             _('Format'),
             _('Display format'),
             '%x',
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         }
 
     def __init__(self):
@@ -225,6 +237,7 @@ class CellRendererDate(gtk.CellRendererText):
         widget.show()
         return widget
 
+
 gobject.type_register(CellRendererDate)
 
 
@@ -234,15 +247,16 @@ class Time(gtk.ComboBoxEntry):
         'value': (gobject.TYPE_PYOBJECT,
             _('Value'),
             _('Displayed value'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         'format': (gobject.TYPE_STRING,
             _('Format'),
             _('Display format'),
             '%X',
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         }
     __gsignals__ = {
-        'time-changed': (gobject.SIGNAL_RUN_LAST | gobject.SIGNAL_ACTION,
+        'time-changed': (
+            gobject.SignalFlags.RUN_LAST | gobject.SignalFlags.ACTION,
             gobject.TYPE_NONE, ()),
         }
 
@@ -312,7 +326,7 @@ class Time(gtk.ComboBoxEntry):
 
     def do_set_property(self, prop, value):
         if prop.name == 'value':
-            if isinstance(value, basestring):
+            if isinstance(value, str):
                 self.__entry.set_text(value)
                 self.parse()
                 value = self.__time
@@ -332,6 +346,7 @@ class Time(gtk.ComboBoxEntry):
         elif prop.name == 'format':
             return self.__format
 
+
 gobject.type_register(Time)
 
 
@@ -341,7 +356,7 @@ class CellRendererTime(gtk.CellRendererText):
             '%X',
             _('Format'),
             _('Display format'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         }
 
     def __init__(self):
@@ -375,6 +390,7 @@ class CellRendererTime(gtk.CellRendererText):
         widget.show()
         return widget
 
+
 gobject.type_register(CellRendererTime)
 
 
@@ -384,20 +400,21 @@ class DateTime(gtk.HBox):
         'value': (gobject.TYPE_PYOBJECT,
             _('Value'),
             _('Displayed value'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         'date-format': (gobject.TYPE_STRING,
             '%x',
             _('Date Format'),
             _('Displayed date format'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         'time-format': (gobject.TYPE_STRING,
             '%X',
             _('Date Format'),
             _('Displayed date format'),
-            gobject.PARAM_READABLE | gobject.PARAM_WRITABLE),
+            gobject.ParamFlags.READABLE | gobject.ParamFlags.WRITABLE),
         }
     __gsignals__ = {
-        'datetime-changed': (gobject.SIGNAL_RUN_LAST | gobject.SIGNAL_ACTION,
+        'datetime-changed': (
+            gobject.SignalFlags.RUN_LAST | gobject.SignalFlags.ACTION,
             gobject.TYPE_NONE, ()),
         }
 
@@ -416,6 +433,10 @@ class DateTime(gtk.HBox):
         self.__time.connect('time-changed',
             lambda e: self.emit('datetime-changed'))
 
+    def parse(self):
+        self.__date.parse()
+        self.__time.parse()
+
     def do_set_property(self, prop, value):
         if prop.name == 'value':
             self.__date.props.value = value
@@ -454,6 +475,7 @@ class DateTime(gtk.HBox):
         self.__date.modify_text(state, color)
         self.__time.child.modify_text(state, color)
 
+
 gobject.type_register(DateTime)
 
 
@@ -464,7 +486,7 @@ def popup_position(widget, popup):
     else:
         x, y = widget.window.get_origin()
     width, height = popup.size_request()
-    popup.move(x + allocation.width - width, y + allocation.height)
+    popup.move(x, y + allocation.height)
 
 
 def popup_show(popup):
@@ -477,13 +499,13 @@ def popup_show(popup):
         (gtk.gdk.BUTTON_PRESS_MASK
             | gtk.gdk.BUTTON_RELEASE_MASK
             | gtk.gdk.POINTER_MOTION_MASK),
-        None, cursor, 0L)
+        None, cursor, 0)
 
 
 def popup_hide(popup):
     popup.hide()
     popup.grab_remove()
-    gtk.gdk.pointer_ungrab(0L)
+    gtk.gdk.pointer_ungrab(0)
 
 
 def timelist_set_list(model, min_, max_, format_):
@@ -493,10 +515,10 @@ def timelist_set_list(model, min_, max_, format_):
         model.append((time.strftime(format_), time))
         hour = time.hour
         minute = time.minute + delta
-        hour += minute / 60
+        hour, minute = divmod(minute, 60)
+        hour += time.hour
         if hour >= 24:
             break
-        minute = minute % 60
         time = datetime.time(hour, minute)
 
 
@@ -531,6 +553,7 @@ def add_operators(widget):
     editable.connect('key-press-event', key_press)
     return widget
 
+
 OPERATORS = {
     gtk.keysyms.S: relativedelta(seconds=-1),
     gtk.keysyms.s: relativedelta(seconds=1),
