@@ -256,11 +256,7 @@ class ViewForm(View):
             if 'states' not in attributes and 'states' in field.attrs:
                 attributes['states'] = field.attrs['states']
             if 'string' not in attributes:
-                if gtk.widget_get_default_direction() == \
-                        gtk.TEXT_DIR_RTL:
-                    attributes['string'] = _(':') + field.attrs['string']
-                else:
-                    attributes['string'] = field.attrs['string'] + _(':')
+                attributes['string'] = field.attrs['string'] + _(':')
         if CONFIG['client.modepda']:
             attributes['xalign'] = 0.0
 
@@ -517,12 +513,13 @@ class ViewForm(View):
         if record:
             # Force to set fields in record
             # Get first the lazy one from the view to reduce number of requests
+            fields = ((name, record.group.fields[name])
+                for name in self.widgets)
             fields = (
                 (name,
                     field.attrs.get('loading', 'eager') == 'eager',
                     len(field.views))
-                for name, field in record.group.fields.items()
-                if self.view_id in field.views)
+                for name, field in fields)
             fields = sorted(fields, key=operator.itemgetter(1, 2))
             for field, _, _ in fields:
                 record[field].get(record)
