@@ -3,8 +3,6 @@
 from .char import Char
 import locale
 
-from tryton.common.entry_position import reset_position
-
 
 class Integer(Char):
     "Integer"
@@ -21,26 +19,16 @@ class Integer(Char):
         self.entry.connect('insert_text', self.sig_insert_text)
         self.factor = float(attrs.get('factor', 1))
 
-    @property
-    def modified(self):
-        if self.record and self.field:
-            entry = self.entry.get_child() if self.autocomplete else self.entry
-            value = entry.get_text() or ''
-            return self.field.get_client(self.record, self.factor) != value
-        return False
-
     def set_value(self, record, field):
         return field.set_client(record, self.entry.get_text(),
             factor=self.factor)
 
-    def display(self, record, field):
-        # skip Char call because set_text doesn't work with int
-        super(Char, self).display(record, field)
+    def get_client_value(self, record, field):
         if not field:
-            self.entry.set_text('')
-            return False
-        self.entry.set_text(field.get_client(record, factor=self.factor))
-        reset_position(self.entry)
+            value = ''
+        else:
+            value = field.get_client(record, factor=self.factor)
+        return value
 
     def sig_insert_text(self, entry, new_text, new_text_length, position):
         value = entry.get_text()
