@@ -254,6 +254,11 @@ class One2Many(Widget):
             o2m_size = None
             size_limit = False
 
+        first = last = False
+        if isinstance(self._position, int):
+            first = self._position <= 1
+            last = self._position >= self._length
+
         self.but_new.set_sensitive(bool(
                 not self._readonly
                 and self.attrs.get('create', True)
@@ -273,10 +278,10 @@ class One2Many(Widget):
                 and access['read']))
         self.but_next.set_sensitive(bool(
                 self._position
-                and self._position < self._length))
+                and not last))
         self.but_pre.set_sensitive(bool(
                 self._position
-                and self._position > 1))
+                and not first))
         if self.attrs.get('add_remove'):
             self.but_add.set_sensitive(bool(
                     not self._readonly
@@ -478,7 +483,7 @@ class One2Many(Widget):
     def _sig_label(self, screen, signal_data):
         self._position = signal_data[0]
         self._length = signal_data[1]
-        if self._position >= 1:
+        if self._position:
             name = str(self._position)
         else:
             name = '_'
